@@ -1884,6 +1884,9 @@ DOUBLE_T string_to_double (char *s, char **end)
   for (int i = 0; i < A68_DOUBLE_DIG; i++) {
     y[i] = 0.0q;
   }
+  if (end != NO_VAR) {
+    (*end) = &(s[0]);
+  }
   while (IS_SPACE (s[0])) {
     s++;
   }
@@ -1912,7 +1915,12 @@ DOUBLE_T string_to_double (char *s, char **end)
     }
     pos++;
   }
-  (*end) = &(s[pos]);
+  while (IS_DIGIT (s[pos])) {
+    pos++;
+  }
+  if (end != NO_VAR) {
+    (*end) = &(s[pos]);
+  }
 // Sum from low to high to preserve precision.
   DOUBLE_T sum = 0.0q;
   for (int i = A68_DOUBLE_DIG - 1; i >= 0; i--) {
